@@ -133,7 +133,7 @@ module SiSU_EPUB_Tune
         end
         SiSU_EPUB_Tune::Tune.new(@data,@md).output
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
