@@ -76,7 +76,7 @@ module SiSU_UpdateControlFlag
         SiSU_Screen::Ansi.new(@md.opt.cmd,'Checking previous output',base_path).green_hi_blue unless @md.opt.cmd =~/q/
         SetCF.new(@md).set_flags
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
