@@ -68,7 +68,7 @@ module SiSU_Plaintext_Format
       @paranum=/(\d+)/m.match(paranum.to_s)[1]
     end
     def display
-      @paranum.gsub(/(\d+)/,"\n[\\1]")
+      @paranum.gsub(/(\d+)/,"\n#{Dx[:ocn_o]}\\1#{Dx[:ocn_c]}")
     end
     def name #unused
       @paranum.gsub(/(\d+)/,'\1')
@@ -97,18 +97,6 @@ module SiSU_Plaintext_Format
     def scr_endnote_body
       "<endnote>#{@txt}</endnote> "
     end
-    def heading_body1
-    end
-    def heading_body2
-    end
-    def heading_body3
-    end
-    def heading_body4
-    end
-    def heading_body5
-    end
-    def heading_body6
-    end
   end
   class XML
   end
