@@ -69,7 +69,9 @@ module SiSU_Source
       @date=SiSU_Env::InfoDate.new.dt
       @env=SiSU_Env::InfoEnv.new(opt.fns)
       @ver=SiSU_Env::InfoVersion.instance.get_version
-      @v=(opt.cmd =~/[VM]/) ? 'v' : ''
+      @v=(@opt.act[:verbose_plus][:set]==:on \
+      || @opt.act[:maintenance][:set]==:on) \
+      ? 'v' : ''
       @particulars=SiSU_Particulars::CombinedSingleton.instance.get_all(opt)
       @file=@particulars.file
       @local_path="#{@file.output_path.sisupod.dir}"
@@ -91,9 +93,11 @@ module SiSU_Source
       }
     end
     def read
-      unless @opt.cmd =~/q/
-        @opt.cmd=~/[MVv]/ \
-        ? SiSU_Screen::Ansi.new(@opt.cmd,'Assemble SiSU source',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").green_hi_blue
+      unless @opt.act[:quiet][:set]==:on
+        (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
+        ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Assemble SiSU source',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").green_hi_blue
         : ''
       end
       unless @opt.fns.empty?
